stm32-metapac

Crates

git

Versions

stm32wb06cc

Flavors

Ctrl

Struct Ctrl 

#[repr(transparent)]
pub struct Ctrl(pub u32);
CTRL register.

Tuple Fields

0: u32

Implementations



impl Ctrl

pub const fn adc_on_off(&self) -> bool

ADC_ON_OFF: 0: power off the ADC 1: power on the ADC.

pub fn set_adc_on_off(&mut self, val: bool)

ADC_ON_OFF: 0: power off the ADC 1: power on the ADC.

pub const fn start_con(&self) -> bool

generate a start pulse to initiate an ADC conversion.

pub fn set_start_con(&mut self, val: bool)

generate a start pulse to initiate an ADC conversion.

pub const fn start_conv(&self) -> bool

START_CONV (1): generate a start pulse to initiate an ADC conversion: 0: no effect 1: start the ADC conversion Note: this bit is set by software and cleared by hardware.

pub fn set_start_conv(&mut self, val: bool)

START_CONV (1): generate a start pulse to initiate an ADC conversion: 0: no effect 1: start the ADC conversion Note: this bit is set by software and cleared by hardware.

pub const fn stop_op_mod(&self) -> bool

stop the on-going OP_MODE (ADC mode, Analog audio mode, Full.

pub fn set_stop_op_mod(&mut self, val: bool)

stop the on-going OP_MODE (ADC mode, Analog audio mode, Full.

pub const fn stop_op_mode(&self) -> bool

STOP_OP_MODE (1): stop the on-going OP_MODE (ADC mode, Analog audio mode, Full mode): 0: no effect 1: stop on-going ADC mode Note: this bit is set by software and cleared by hardware. When setting the STOP_MODE_OP, the user has to wait around 10 us before to start a new ADC conversion by setting the START_CONV bit.

pub fn set_stop_op_mode(&mut self, val: bool)

STOP_OP_MODE (1): stop the on-going OP_MODE (ADC mode, Analog audio mode, Full mode): 0: no effect 1: stop on-going ADC mode Note: this bit is set by software and cleared by hardware. When setting the STOP_MODE_OP, the user has to wait around 10 us before to start a new ADC conversion by setting the START_CONV bit.

pub const fn dig_aud_mode(&self) -> bool

enable the digital audio mode (the data path uses. the decimation filter).

pub fn set_dig_aud_mode(&mut self, val: bool)

enable the digital audio mode (the data path uses. the decimation filter).

pub const fn test_mode(&self) -> bool

TEST_MODE: select the functional or the test mode of the ADC: 0: functional mode (one of the four main functional modes is used) 1: test mode (for debug, test, calibration).

pub fn set_test_mode(&mut self, val: bool)

TEST_MODE: select the functional or the test mode of the ADC: 0: functional mode (one of the four main functional modes is used) 1: test mode (for debug, test, calibration).

pub const fn adc_ldo_ena(&self) -> bool

ADC_LDO_ENA: enable the LDO associated to the ADC block: 0: disable the ADC LDO 1: enable the ADC LDO.

pub fn set_adc_ldo_ena(&mut self, val: bool)

ADC_LDO_ENA: enable the LDO associated to the ADC block: 0: disable the ADC LDO 1: enable the ADC LDO.