Struct IrqEnable
#[repr(transparent)]pub struct IrqEnable(pub u32);Expand description
IRQ_ENABLE register.
Tuple Fields
0: u32Implementations
impl IrqEnable
impl IrqEnable
pub const fn eoc_irq(&self) -> bool
pub const fn eoc_irq(&self) -> bool
EOC_IRQ (Used in test mode only): set when the ADC conversion is completed. When read, provide the status of the interrupt: 0: ADC conversion is not completed 1: ADC conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub fn set_eoc_irq(&mut self, val: bool)
pub fn set_eoc_irq(&mut self, val: bool)
EOC_IRQ (Used in test mode only): set when the ADC conversion is completed. When read, provide the status of the interrupt: 0: ADC conversion is not completed 1: ADC conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub const fn eoc_irq_ena(&self) -> bool
pub const fn eoc_irq_ena(&self) -> bool
(Used in test mode only): End of ADC conversion interrupt enable.
pub fn set_eoc_irq_ena(&mut self, val: bool)
pub fn set_eoc_irq_ena(&mut self, val: bool)
(Used in test mode only): End of ADC conversion interrupt enable.
pub const fn eods_irq(&self) -> bool
pub const fn eods_irq(&self) -> bool
EODS_IRQ: set when the Down Sampler conversion is completed. When read, provide the status of the interrupt: 0: Down Sampler conversion is not completed 1: Down Sampler conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub fn set_eods_irq(&mut self, val: bool)
pub fn set_eods_irq(&mut self, val: bool)
EODS_IRQ: set when the Down Sampler conversion is completed. When read, provide the status of the interrupt: 0: Down Sampler conversion is not completed 1: Down Sampler conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub const fn eods_irq_ena(&self) -> bool
pub const fn eods_irq_ena(&self) -> bool
End of conversion interrupt enable for the Down Sampler output.
pub fn set_eods_irq_ena(&mut self, val: bool)
pub fn set_eods_irq_ena(&mut self, val: bool)
End of conversion interrupt enable for the Down Sampler output.
pub const fn eodf_irq_ena(&self) -> bool
pub const fn eodf_irq_ena(&self) -> bool
End of conversion interrupt enable for the decimation filter output.
pub fn set_eodf_irq_ena(&mut self, val: bool)
pub fn set_eodf_irq_ena(&mut self, val: bool)
End of conversion interrupt enable for the decimation filter output.
pub const fn eos_irq(&self) -> bool
pub const fn eos_irq(&self) -> bool
EOS_IRQ: set when a sequence of conversion is completed. When read, provide the status of the interrupt: 0: sequence of conversion is not completed 1: sequence of conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub fn set_eos_irq(&mut self, val: bool)
pub fn set_eos_irq(&mut self, val: bool)
EOS_IRQ: set when a sequence of conversion is completed. When read, provide the status of the interrupt: 0: sequence of conversion is not completed 1: sequence of conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub const fn eos_irq_ena(&self) -> bool
pub const fn eos_irq_ena(&self) -> bool
End of regular sequence interrupt enable.
pub fn set_eos_irq_ena(&mut self, val: bool)
pub fn set_eos_irq_ena(&mut self, val: bool)
End of regular sequence interrupt enable.
pub const fn awd_irq(&self) -> bool
pub const fn awd_irq(&self) -> bool
AWD_IRQ: set when an analog watchdog event occurs. When read, provide the status of the interrupt: 0: no analog watchdog event occurred 1: analog watchdog event has occurred Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub fn set_awd_irq(&mut self, val: bool)
pub fn set_awd_irq(&mut self, val: bool)
AWD_IRQ: set when an analog watchdog event occurs. When read, provide the status of the interrupt: 0: no analog watchdog event occurred 1: analog watchdog event has occurred Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub const fn awd_irq_ena(&self) -> bool
pub const fn awd_irq_ena(&self) -> bool
analog watchdog interrupt enable.
pub fn set_awd_irq_ena(&mut self, val: bool)
pub fn set_awd_irq_ena(&mut self, val: bool)
analog watchdog interrupt enable.
pub const fn ovr_ds_irq(&self) -> bool
pub const fn ovr_ds_irq(&self) -> bool
OVR_DS_IRQ: set to indicate a Down Sampler overrun (at least one data is lost) When read, provide the status of the interrupt: 0: no overrun occurred 1: overrun occurred Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub fn set_ovr_ds_irq(&mut self, val: bool)
pub fn set_ovr_ds_irq(&mut self, val: bool)
OVR_DS_IRQ: set to indicate a Down Sampler overrun (at least one data is lost) When read, provide the status of the interrupt: 0: no overrun occurred 1: overrun occurred Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.
pub const fn ovr_ds_irq_ena(&self) -> bool
pub const fn ovr_ds_irq_ena(&self) -> bool
Down Sampler overrun interrupt enable.
pub fn set_ovr_ds_irq_ena(&mut self, val: bool)
pub fn set_ovr_ds_irq_ena(&mut self, val: bool)
Down Sampler overrun interrupt enable.
pub const fn ovr_df_irq_ena(&self) -> bool
pub const fn ovr_df_irq_ena(&self) -> bool
decimation filter overrun interrupt enable.
pub fn set_ovr_df_irq_ena(&mut self, val: bool)
pub fn set_ovr_df_irq_ena(&mut self, val: bool)
decimation filter overrun interrupt enable.
pub const fn df_ovrfl_irq_ena(&self) -> bool
pub const fn df_ovrfl_irq_ena(&self) -> bool
decimation filter saturation interrupt enable.
pub fn set_df_ovrfl_irq_ena(&mut self, val: bool)
pub fn set_df_ovrfl_irq_ena(&mut self, val: bool)
decimation filter saturation interrupt enable.