stm32-metapac

Crates

git

Versions

stm32wb06cc

Flavors

IrqStatus

Struct IrqStatus 

#[repr(transparent)]
pub struct IrqStatus(pub u32);
IRQ_STATUS register.

Tuple Fields

0: u32

Implementations



impl IrqStatus

pub const fn eoc_irq(&self) -> bool

EOC_IRQ (Used in test mode only): set when the ADC conversion is completed. When read, provide the status of the interrupt: 0: ADC conversion is not completed 1: ADC conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub fn set_eoc_irq(&mut self, val: bool)

EOC_IRQ (Used in test mode only): set when the ADC conversion is completed. When read, provide the status of the interrupt: 0: ADC conversion is not completed 1: ADC conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub const fn eods_irq(&self) -> bool

EODS_IRQ: set when the Down Sampler conversion is completed. When read, provide the status of the interrupt: 0: Down Sampler conversion is not completed 1: Down Sampler conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub fn set_eods_irq(&mut self, val: bool)

EODS_IRQ: set when the Down Sampler conversion is completed. When read, provide the status of the interrupt: 0: Down Sampler conversion is not completed 1: Down Sampler conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub const fn eodf_irq(&self) -> bool

set when the decimation filter conversion is completed.

pub fn set_eodf_irq(&mut self, val: bool)

set when the decimation filter conversion is completed.

pub const fn eos_irq(&self) -> bool

EOS_IRQ: set when a sequence of conversion is completed. When read, provide the status of the interrupt: 0: sequence of conversion is not completed 1: sequence of conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub fn set_eos_irq(&mut self, val: bool)

EOS_IRQ: set when a sequence of conversion is completed. When read, provide the status of the interrupt: 0: sequence of conversion is not completed 1: sequence of conversion is completed Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub const fn awd_irq(&self) -> bool

AWD_IRQ: set when an analog watchdog event occurs. When read, provide the status of the interrupt: 0: no analog watchdog event occurred 1: analog watchdog event has occurred Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub fn set_awd_irq(&mut self, val: bool)

AWD_IRQ: set when an analog watchdog event occurs. When read, provide the status of the interrupt: 0: no analog watchdog event occurred 1: analog watchdog event has occurred Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub const fn ovr_ds_irq(&self) -> bool

OVR_DS_IRQ: set to indicate a Down Sampler overrun (at least one data is lost) When read, provide the status of the interrupt: 0: no overrun occurred 1: overrun occurred Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub fn set_ovr_ds_irq(&mut self, val: bool)

OVR_DS_IRQ: set to indicate a Down Sampler overrun (at least one data is lost) When read, provide the status of the interrupt: 0: no overrun occurred 1: overrun occurred Writing this bit clears the status of the interrupt: 0: no effect 1: clear the interrupt.

pub const fn ovr_df_irq(&self) -> bool

set to indicate a decimation filter overrun (a data is lost).

pub fn set_ovr_df_irq(&mut self, val: bool)

set to indicate a decimation filter overrun (a data is lost).

pub const fn df_ovrfl_irq(&self) -> bool

set to indicate the decimation filter is saturated.

pub fn set_df_ovrfl_irq(&mut self, val: bool)

set to indicate the decimation filter is saturated.